@@ -45,8 +45,4 @@ class ForensicImageBuilder(cdk.Construct):
                                    subnet_type=ec2.SubnetType.PUBLIC
                                ),
                            ])
-        cdk.CfnOutput(self, "vpc_id",
-                      export_name="vpc-id",
-                      value=vpc.vpc_id,
-                      description="The VPC for the AMI Builder")
         return vpc
\ No newline at end of file
